<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=is
// ** ne pas modifier le fichier **

return [

	// F
	'forum_acces_refuse' => 'Þú hefur ekki lengur aðgang að þessari umræðu.',
	'forum_cliquer_retour' => 'Smellið <a href=\'@retour_forum@\'>ici</a> til að halda áfram',
	'forum_message_definitif' => 'Endanleg skilaboð : vistið',
	'forum_poste_par' => 'Skilaboð send@parauteur@ í framhaldi greinar þinnar.', # MODIF
	'forum_texte' => 'Skrifið skilaboðin :', # MODIF
	'forum_titre' => 'Fyrirsögn :', # MODIF
	'forum_valider' => 'Staðfesta valið',
	'forum_voir_avant' => 'Skoða skilaboðið áður en það verður sent', # MODIF
	'forum_votre_email' => 'Netfang þitt :', # MODIF
	'forum_votre_nom' => 'Nafn (notandanafn) :', # MODIF
	'forum_vous_inscrire' => 'skráðu þig inn </a> fyrst.',

	// I
	'icone_poster_message' => 'Senda skilaboð',
	'icone_supprimer_message' => 'Eyða þessum skilaboðum',
	'icone_valider_message' => 'Staðfesta skilaboðin',
];
